@@ -1,5 +1,5 @@
 package Thrift::API::HiveClient2;
-$Thrift::API::HiveClient2::VERSION = '0.024';
+$Thrift::API::HiveClient2::VERSION = '0.025';
 {
   $Thrift::API::HiveClient2::DIST = 'Thrift-API-HiveClient2';
 }
@@ -16,6 +16,7 @@ use List::MoreUtils 'zip';
 
 use Thrift;
 use Thrift::Socket;
+use Thrift::SSLSocket;
 use Thrift::BufferedTransport;
 
 # Protocol loading is done dynamically later.
@@ -73,6 +74,11 @@ has sasl => (
     default => 0,
 );
 
+has use_ssl => (
+    is      => 'ro',
+    default => 0,
+);
+
 # Kerberos principal
 # Usually in the format 'hive/{hostname}@REALM.COM';
 has principal => (
@@ -130,7 +136,16 @@ sub _set_sasl {
 sub BUILD {
     my $self = shift;
 
-    $self->_set_socket( Thrift::Socket->new( $self->host, $self->port ) )
+    my $thrift_socket;
+    
+    if( $self->use_ssl ) {
+     $thrift_socket = Thrift::SSLSocket->new( $self->host, $self->port );
+    }
+    else {
+     $thrift_socket = Thrift::Socket->new( $self->host, $self->port );
+    }
+
+    $self->_set_socket( $thrift_socket )
         unless $self->_socket;
     $self->_socket->setRecvTimeout( $self->timeout * 1000 );
 
@@ -532,7 +547,7 @@ Thrift::API::HiveClient2 - Perl to HiveServer2 Thrift API wrapper
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =for Pod::Coverage BUILD DEMOLISH
 
@@ -564,6 +579,10 @@ Kerberos principal. Default is not set. See the L</WARNING> section.
 
 Enables authentication. Default is not set. See the L</WARNING> section.
 
+=head3 use_ssl
+
+uses Thrift::SSLSocket if enabled by setting 1. By default set to 0 and uses Thrift::Socket
+
 =head3 timeout
 
 Seconds timeout, defaults to 1 hour.
